[frogr] Add 'Quit' button to app menu for OS X



commit cdb6292275e90442b1da3fe36bd575c0e0dd3eaf
Author: Mario Sanchez Prada <msanchez gnome org>
Date:   Wed Dec 26 12:29:19 2012 +0100

    Add 'Quit' button to app menu for OS X

 src/frogr-main-view.c |    8 ++++++--
 1 files changed, 6 insertions(+), 2 deletions(-)
---
diff --git a/src/frogr-main-view.c b/src/frogr-main-view.c
index 71ee5ae..30660aa 100644
--- a/src/frogr-main-view.c
+++ b/src/frogr-main-view.c
@@ -816,11 +816,15 @@ _tweak_app_menu_for_mac (FrogrMainView *self)
   /* Hide the Section including the 'Help' menu item */
   g_menu_remove (G_MENU (priv->app_menu), 2);
 
-  /* The section removed contained the 'About' item, so create a new
-     one and place it in at the beginning to make it more OSX-ish */
+  /* The section removed contained the 'About' and 'Quit' items, so
+     create new ones and place them in their right places */
   menu = G_MENU_MODEL (g_menu_new ());
   g_menu_append_item (G_MENU (menu), g_menu_item_new (_("_About"), "app.about"));
   g_menu_insert_section (G_MENU (priv->app_menu), 0, NULL, menu);
+
+  menu = G_MENU_MODEL (g_menu_new ());
+  g_menu_append_item (G_MENU (menu), g_menu_item_new (_("_Quit"), "app.quit"));
+  g_menu_insert_section (G_MENU (priv->app_menu), 3, NULL, menu);
 }
 #endif
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]